@@ -22,8 +22,9 @@ from guildbotics.entities.team import Person
 from guildbotics.integrations.github.github_ticket_manager import GitHubTicketManager
 from guildbotics.integrations.github.github_utils import GitHubAppAuth
 from guildbotics.intelligences.functions import talk_as
-from guildbotics.modes.comment_mode import CommentMode
 from guildbotics.runtime import Context
+from guildbotics.templates.commands.workflows.modes import comment_mode
+from guildbotics.templates.commands.workflows.modes.util import checkout
 from guildbotics.utils.fileio import (
     CONFIG_PATH,
     get_template_path,
@@ -51,6 +52,7 @@ class ProjectConfig(BaseModel):
     llm_api_type_label: str = Field(default="")
     google_api_key: str = Field(default="")
     openai_api_key: str = Field(default="")
+    anthropic_api_key: str = Field(default="")
     cli_agent: str = Field(default="")
     cli_agent_label: str = Field(default="")
     github_project_url: str = Field(default="")
@@ -59,6 +61,8 @@ class ProjectConfig(BaseModel):
     owner: str = Field(default="")
     project_id: str = Field(default="")
     repository_name: str = Field(default="")
+    repo_access_label: str = Field(default="")
+    repo_base_url: str = Field(default="https://github.com")
 
 
 class PersonConfig(BaseModel):
@@ -81,11 +85,12 @@ class PersonConfig(BaseModel):
 
 class SimpleSetupTool(SetupTool):
 
-    def get_context(self) -> Context:
+    def get_context(self, message: str = "") -> Context:
         return Context.get_default(
             SimpleLoaderFactory(),
             SimpleIntegrationFactory(),
             SimpleBrainFactory(),
+            message=message,
         )
 
     def init_project(self) -> None:
@@ -154,6 +159,7 @@ class SimpleSetupTool(SetupTool):
         llm_api_type_map = {
             "OpenAI": "openai",
             "Google Gemini": "gemini",
+            "Anthropic Claude": "anthropic",
         }
 
         config.llm_api_type_label = questionary.select(
@@ -171,11 +177,16 @@ class SimpleSetupTool(SetupTool):
                 config.openai_api_key = questionary.text(
                     t("cli.openai_api_key_prompt")
                 ).ask()
+            if config.llm_api_type == "anthropic":
+                config.anthropic_api_key = questionary.text(
+                    t("cli.anthropic_api_key_prompt")
+                ).ask()
 
         # Step 5. CLI Agent Selection
         cli_agent_map = {
             "OpenAI Codex CLI": "codex",
             "Gemini CLI": "gemini",
+            "Claude Code": "claude",
         }
 
         config.cli_agent_label = questionary.select(
@@ -196,7 +207,17 @@ class SimpleSetupTool(SetupTool):
             validate=lambda text: self.parse_github_repository_url(text, config),
         ).ask()
 
-        # Step 7. Configuration Summary
+        # Step 7. Repository Access Method (HTTPS / SSH)
+        access_map = {
+            t("cli.repo_access_https"): "https://github.com",
+            t("cli.repo_access_ssh"): "ssh://git@github.com",
+        }
+        config.repo_access_label = questionary.select(
+            t("cli.repo_access_prompt"), choices=list(access_map.keys())
+        ).ask()
+        config.repo_base_url = access_map[config.repo_access_label]
+
+        # Step 8. Configuration Summary
         click.echo(f"\n{t('cli.config_content')} :")
         click.echo(f"  {t('cli.config_lang')} : {config.language_label}")
         click.echo(f"  {t('cli.config_target_directory')} : {config.config_dir_label}")
@@ -211,6 +232,10 @@ class SimpleSetupTool(SetupTool):
                 click.echo(
                     f"  {t('cli.config_openai_api_key')} : {config.openai_api_key}"
                 )
+            if config.llm_api_type == "anthropic":
+                click.echo(
+                    f"  {t('cli.config_anthropic_api_key')} : {config.anthropic_api_key}"
+                )
         click.echo(f"  {t('cli.config_cli_agent')} : {config.cli_agent_label}")
         click.echo(
             f"  {t('cli.config_github_project_url')} : {config.github_project_url}"
@@ -218,12 +243,13 @@ class SimpleSetupTool(SetupTool):
         click.echo(
             f"  {t('cli.config_github_repository_url')} : {config.github_repository_url}\n"
         )
+        click.echo(f"  {t('cli.config_repo_access')} : {config.repo_access_label}")
 
         if not questionary.confirm(t("cli.config_confirm"), default=True).ask():
             click.echo(t("cli.config_cancel"))
             return
 
-        # Step 8. Configuration File Creation
+        # Step 9. Configuration File Creation
         project_config_template = (TEMPLATE_PATH / "project.yml").read_text()
         project_config = project_config_template.format(
             language=config.language,
@@ -231,6 +257,7 @@ class SimpleSetupTool(SetupTool):
             owner=config.owner,
             project_id=config.project_id,
             project_url=config.github_project_url,
+            repo_base_url=config.repo_base_url,
         )
 
         project_config_file = config.config_dir / "team/project.yml"
@@ -268,6 +295,7 @@ class SimpleSetupTool(SetupTool):
             env_file = env_file_template.format(
                 google_api_key=f"GOOGLE_API_KEY={config.google_api_key}",
                 openai_api_key=f"OPENAI_API_KEY={config.openai_api_key}",
+                anthropic_api_key=f"ANTHROPIC_API_KEY={config.anthropic_api_key}",
             )
 
             if config.env_file_option == "overwrite":
@@ -560,8 +588,8 @@ class SimpleSetupTool(SetupTool):
                     )
 
                     # Check Git and CLI Agent Settings
-                    comment_mode = CommentMode(c)
-                    res = await comment_mode.run(messages)
+                    git_tool = await checkout(c)
+                    res = await comment_mode.main(c, messages, git_tool)
 
                     print()
                     print("----- API Agent Output -----")
@@ -737,3 +765,6 @@ class SimpleSetupTool(SetupTool):
             f"{GITHUB_URL}{config.owner}/{config.repository_name}"
         )
         return True
+
+    def get_default_routines(self) -> list[str]:
+        return ["workflows/ticket_driven_workflow"]
