@@ -1,3 +1,4 @@
+import re
 from logging import Logger
 from typing import Any, ClassVar, cast
 
@@ -19,7 +20,6 @@ from guildbotics.integrations.github.github_utils import (
 )
 from guildbotics.integrations.ticket_manager import TicketManager
 from guildbotics.intelligences.common import Labels
-from guildbotics.modes.mode_base import ModeBase
 from guildbotics.utils.i18n_tool import t
 
 
@@ -102,7 +102,7 @@ class GitHubTicketManager(TicketManager):
                         "name": name,
                         "description": mode or "",
                     }
-                    for name, mode in ModeBase.get_available_modes(self.team).items()
+                    for name, mode in Labels(Task.get_available_modes()).items()
                 ],
             },
             GitHubTicketManager.FIELD_ROLE: {
@@ -567,7 +567,8 @@ class GitHubTicketManager(TicketManager):
         hosting_service = GitHubCodeHostingService(
             self.person, self.team, task.repository
         )
-        if not url.startswith(hosting_service.repo_base_url):
+        # Check PR URL against GitHub web base, independent of clone scheme
+        if not url.startswith("https://github.com/"):
             return False  # Not a PR URL
 
         comments = await hosting_service.get_pull_request_comments(url)
@@ -793,9 +794,21 @@ class GitHubTicketManager(TicketManager):
         issue_data = issue_resp.json()
         author_login = (issue_data.get("user") or {}).get("login")
 
-        # Prepend mention to the issue author unless we are the author
+        # Prepend mention to the issue author unless we are the author.
+        # Avoid adding only when the body already mentions the issue author
+        # (case-insensitive) to prevent duplicates.
         if author_login and author_login != self.username:
-            comment = f"@{author_login}\n\n{comment}"
+            # Explicitly check if the issue author is already mentioned.
+            # GitHub usernames are case-insensitive, so we use re.IGNORECASE.
+            author_mention_re = (
+                r"(^|[^A-Za-z0-9_])@" + re.escape(author_login) + r"(?=$|[^A-Za-z0-9-])"
+            )
+            has_author_mention = bool(
+                re.search(author_mention_re, comment, flags=re.IGNORECASE)
+            )
+
+            if not has_author_mention:
+                comment = f"@{author_login}\n\n{comment}"
         if is_proxy_agent(self.person):
             comment = f"{comment}\n\n{get_proxy_agent_signature(self.person)}"
         await client.post(
