@@ -13,7 +13,7 @@ class Brain(ABC):
         name: str,
         logger: Logger,
         description: str = "",
-        instructions: str = "",
+        template_engine: str = "default",
         response_class: Type[BaseModel] | None = None,
     ):
         """
@@ -23,14 +23,14 @@ class Brain(ABC):
             name (str): Name of the intelligence.
             logger (Logger): Logger instance for logging.
             description (str): Description of the intelligence.
-            instructions (str): Instructions for using the intelligence.
+            template_engine (str): Template engine to use ("default" or "jinja2").
             response_class (Type[BaseModel] | None): Class for the response model.
         """
         self.person_id = person_id
         self.name = name
         self.logger = logger
         self.description = description
-        self.instructions = instructions
+        self.template_engine = template_engine
         self.response_class = response_class
 
     @abstractmethod
